==> vue-ui-0.10.63.tgz: package/src/components/UiPictureModel.ts <==
import {BreakpointKey} from "@/config/responsiveConfig"
import urlUtil from "@/util/urlUtil"
import {uiComponentConfig} from "@/config/uiComponentConfig"
import {supportWebp} from "@/config/clientContext"

export type ResponsiveSrc = {
  [key in (BreakpointKey | "default")]?: {
    media?: string,
    src?: string,
    srcset?: string
  }
}

/**
 * AbsoluteUrl이고, 같은 fileUrl일 때, quality 파라미터(?q=80/&q=80)를 만든다.
 */
export const getQualityParamInAbsUrl = (src: string,
                                        quality: number) => {
  // AbsoluteUrl이 아니면 'q=' 만들지 않는다.
  if (!urlUtil.isAbsoluteUrl(src)) return ''

  // fileUrlPrefix가 다르면 'q=' 만들지 않는다.
  const isSameFileUrlPrefix = !!src.match(uiComponentConfig.fileUrlPrefix)
  if (!isSameFileUrlPrefix) return ''


  // fileUrlPrefix가 같은데, 이미 'q=' 이 있다면 만들지 않는다.
  const isExistQualityParam = !!src.match(/q=[0-9]+/g)
  if (isExistQualityParam) return ''


  // url에 ?가 있다면 &q를 만들고 없다면 ?q를 만든다.
  const isExistQueryBeginner = src.match(/\?.*=/g)
  const qualityParam = isExistQueryBeginner ? '&q' : '?q'
  return `${qualityParam}=${quality}`
}

/**
 *  img 태그 또는 picture 태그에 들어갈 src를 만든다.
 */
export const createImageUrl = (quality: number,
                               imageResizeAvailable: boolean,
                               src?: string,
                               width?: number,
                               height?: number): string | undefined => {
  // src가 없다면 undefined를 리턴한다.
  if (!src) return undefined

  //absoluteUrl이면 qualityParam를 붙여서 리턴한다.
  if (urlUtil.isAbsoluteUrl(src)) {

    if (!urlUtil.isSameFileUrlPrefix(src)) return src

    const qualityParam = quality >= 0 ? quality : uiComponentConfig.imageQuality
    return src + getQualityParamInAbsUrl(src, qualityParam)
  }

  const _src = urlUtil.isS3ImageUrl(src) ? uiComponentConfig.fileUrlPrefix + src : src
  // resize 가 가능하면 image resize parameter 를 붙인다.
  return imageResizeAvailable
      ? _src + getResizeParams(quality, width, height)
      : _src

}

/**
 *  resize에 필요한 파라미터를 만든다.
 */
const getResizeParams = (quality?: number,
                         width?: number,
                         height?: number) => {
  const format = supportWebp ? '?f=webp' : '?'
  const qualityParam = (quality && quality > 0) ? `&q=${quality}` : `&q=${uiComponentConfig.imageQuality}`
  const widthParam = width ? `&w=${width}` : ''
  const heightParam = height ? `&h=${height}` : ''
  return `${format}${qualityParam}${widthParam}${heightParam}`
}

==> vue-ui-0.11.11.tgz: package/src/components/UiPictureModel.ts <==
import {BreakpointKey} from "@/config/responsiveConfig"
import urlUtil from "@/util/urlUtil"
import {uiComponentConfig} from "@/config/uiComponentConfig"
import {supportWebp} from "@/config/clientContext"

export type ResponsiveSrc = {
  [key in (BreakpointKey | "default")]?: {
    media?: string,
    src?: string,
    srcset?: string
  }
}

/**
 * AbsoluteUrl이고, 같은 fileUrl일 때, quality 파라미터(?q=80/&q=80)를 만든다.
 */
export const getQualityParamInAbsUrl = (src: string,
                                        quality: number) => {
  // AbsoluteUrl이 아니면 'q=' 만들지 않는다.
  if (!urlUtil.isAbsoluteUrl(src)) return ''

  // fileUrlPrefix가 다르면 'q=' 만들지 않는다.
  const isSameFileUrlPrefix = !!src.match(uiComponentConfig.fileUrlPrefix)
  if (!isSameFileUrlPrefix) return ''


  // fileUrlPrefix가 같은데, 이미 'q=' 이 있다면 만들지 않는다.
  const isExistQualityParam = !!src.match(/q=.+[0-9]/g)
  if (isExistQualityParam) return ''


  // url에 ?가 있다면 &q를 만들고 없다면 ?q를 만든다.
  const isExistQueryBeginner = src.match(/\?.*=/g)
  const qualityParam = isExistQueryBeginner ? '&q' : '?q'
  return `${qualityParam}=${quality}`
}

/**
 *  <img/>나 <picture/>에 들어갈 src를 만든다.
 */
export const createImageUrl = (quality: number,
                               imageResizeAvailable: boolean,
                               src?: string,
                               width?: number,
                               height?: number): string | undefined => {
  // src가 없다면 undefined를 리턴한다.
  if (!src) return undefined

  //absoluteUrl이면 qualityParam를 붙여서 리턴한다.
  if (urlUtil.isAbsoluteUrl(src)) {

    if (!urlUtil.isSameFileUrlPrefix(src)) return src

    const qualityParam = quality > 0 ? quality : uiComponentConfig.imageQuality
    return src + getQualityParamInAbsUrl(src, qualityParam)
  }

  const _src = urlUtil.isS3ImageUrl(src) ? uiComponentConfig.fileUrlPrefix + src : src
  // resize 가 가능하면 image resize parameter 를 붙인다.
  return imageResizeAvailable
      ? _src + getResizeParams(quality, width, height)
      : _src

}

/**
 *  resize에 필요한 파라미터를 만든다.
 */
const getResizeParams = (quality?: number,
                         width?: number,
                         height?: number) => {
  const format = supportWebp ? '?f=webp' : '?'
  const qualityParam = (quality && quality > 0) ? `&q=${quality}` : `&q=${uiComponentConfig.imageQuality}`
  const widthParam = width ? `&w=${width}` : ''
  const heightParam = height ? `&h=${height}` : ''
  return `${format}${qualityParam}${widthParam}${heightParam}`
}
